.. _pylint_in_flymake:

Using Pylint through Flymake in Emacs
=====================================

.. warning::
    epylint was deprecated in 2.16.0 and targeted for deletion in 3.0.0.
    All emacs and flymake related files were removed and their support will
    now happen in an external repository: https://github.com/emacsorphanage/pylint.
